import test from 'ava';
import getAttributesSpecifiedFromArray from '.';

const attributes_required = [
    'beam1_present',
    'beam1_stable',
    'beam2_present',
    'beam2_stable',
    'bpix_ready',
    'castor_ready',
    'cms_active',
    'cscm_ready',
    'cscp_ready',
    'dt0_ready',
    'dtm_ready',
    'dtp_ready',
    'ebm_ready',
    'ebp_ready',
    'eem_ready',
    'eep_ready',
    'esm_ready',
    'esp_ready',
    'fpix_ready',
    'hbhea_ready',
    'hbheb_ready',
    'hbhec_ready',
    'hf_ready',
    'ho_ready',
    'rp_sect_45_ready',
    'rp_sect_56_ready',
    'rp_time_ready',
    'rpc_ready',
    'tecm_ready',
    'tecp_ready',
    'tibtid_ready',
    'tob_ready',
    'zdc_read'
];
const run = {
    id: '321393',
    components: [
        'CSC',
        'CTPPS',
        'CTPPS_TOT',
        'DAQ',
        'DCS',
        'DQM',
        'DT',
        'ECAL',
        'ES',
        'GEM',
        'HCAL',
        'PIXEL',
        'RPC',
        'SCAL',
        'TCDS',
        'TRACKER',
        'TRG'
    ],
    l1_key: 'l1_trg_collisions2018/v51',
    duration: 3390,
    b_field: 3.801,
    tier0_transfer: true,
    l1_triggers_counter: 223764182,
    hlt_physics_throughput: 1.35019286,
    init_lumi: 1.81413613,
    delivered_lumi: 24.60627148,
    recorded_lumi: 0.0633478,
    cmssw_version: 'CMSSW_10_1_9_patch1',
    energy: 6499,
    end_lumi: 1.81335566,
    hlt_physics_rate: 1430.485,
    fill_number: 7058,
    l1_hlt_mode: 'collisions2018',
    end_time: '2018-08-17T05:32:58Z',
    trigger_mode: 'l1_hlt_collisions2018/v186',
    fill_type_party2: 'PROTON',
    fill_type_party1: 'PROTON',
    initial_prescale_index: 2,
    sequence: 'GLOBAL-RUN',
    start_time: '2018-08-17T05:32:35Z',
    hlt_physics_size: 4500.717,
    fill_type_runtime: 'PROTONS',
    hlt_key: '/cdaq/physics/Run2018/2e34/v3.3.0/HLT/V9',
    clock_type: 'LHC',
    l1_rate: 66663.21,
    l1_menu: 'L1Menu_Collisions2018_v2_0_0',
    run_number: 321393,
    stable_beam: true,
    hlt_physics_counter: 4768364,
    csc_included: true,
    ctpps_included: true,
    ctpps_tot_included: true,
    daq_included: true,
    dcs_included: true,
    dqm_included: true,
    dt_included: true,
    ecal_included: true,
    es_included: true,
    gem_included: true,
    hcal_included: true,
    pixel_included: true,
    rpc_included: true,
    scal_included: true,
    tcds_included: true,
    tracker_included: true,
    trg_included: true,
    rp_time_ready: false,
    cscp_ready: true,
    physics_flag: true,
    dt0_ready: true,
    beam1_present: true,
    bpix_ready: true,
    ho_ready: true,
    dtp_ready: true,
    tecm_ready: true,
    lumisection_number: 1,
    tibtid_ready: true,
    fpix_ready: true,
    rpc_ready: true,
    rp_sect_56_ready: true,
    castor_ready: false,
    esp_ready: true,
    eep_ready: true,
    hbhea_ready: true,
    ebm_ready: true,
    dtm_ready: true,
    eem_ready: true,
    esm_ready: true,
    tecp_ready: true,
    ebp_ready: true,
    hf_ready: true,
    rp_sect_45_ready: true,
    cscm_ready: true,
    cms_active: true,
    zdc_ready: false,
    hbheb_ready: true,
    tob_ready: true,
    beam1_stable: true,
    hbhec_ready: true,
    beam2_stable: true,
    beam2_present: true,
    beams_present_and_stable: true,
    class: 'COLLISSIONS'
};

test('check attributes', t => {
    t.deepEqual(getAttributesSpecifiedFromArray(run, attributes_required), {
        rp_time_ready: false,
        cscp_ready: true,
        dt0_ready: true,
        beam1_present: true,
        bpix_ready: true,
        ho_ready: true,
        dtp_ready: true,
        tecm_ready: true,
        tibtid_ready: true,
        fpix_ready: true,
        rpc_ready: true,
        rp_sect_56_ready: true,
        castor_ready: false,
        esp_ready: true,
        eep_ready: true,
        hbhea_ready: true,
        ebm_ready: true,
        dtm_ready: true,
        eem_ready: true,
        esm_ready: true,
        tecp_ready: true,
        ebp_ready: true,
        hf_ready: true,
        rp_sect_45_ready: true,
        cscm_ready: true,
        cms_active: true,
        hbheb_ready: true,
        tob_ready: true,
        beam1_stable: true,
        hbhec_ready: true,
        beam2_stable: true,
        beam2_present: true
    });
});
